//! All the notcurses widgets.

mod menu;
mod multiselector;
mod plot;
mod progbar;
mod reader;
mod reel;
mod selector;
mod tabbed;
mod tree;

pub use menu::*;
pub use multiselector::*;
pub use plot::*;
pub use progbar::*;
pub use reader::*;
pub use reel::*;
pub use selector::*;
pub use tabbed::*;
pub use tree::*;
